@@ -56,14 +56,14 @@ class Txn(object):
         self._read_only = read_only
         self._best_effort = best_effort
 
-    def query(self, query, variables=None, timeout=None, metadata=None, credentials=None):
+    def query(self, query, variables=None, timeout=None, metadata=None, credentials=None, resp_format="JSON"):
         """Executes a query operation."""
-        req = self.create_request(query=query, variables=variables)
+        req = self.create_request(query=query, variables=variables, resp_format=resp_format)
         return self.do_request(req, timeout=timeout, metadata=metadata, credentials=credentials)
 
-    def async_query(self, query, variables=None, timeout=None, metadata=None, credentials=None):
+    def async_query(self, query, variables=None, timeout=None, metadata=None, credentials=None, resp_format="JSON"):
         """Async version of query."""
-        req = self.create_request(query=query, variables=variables)
+        req = self.create_request(query=query, variables=variables, resp_format=resp_format)
         return self.async_do_request(req, timeout=timeout, metadata=metadata, credentials=credentials)
 
     def mutate(self, mutation=None, set_obj=None, del_obj=None,
@@ -95,6 +95,7 @@ class Txn(object):
                 raise errors.TransactionError('Readonly transaction cannot run mutations')
             self._mutated = True
 
+        request.hash = self._ctx.hash
         new_metadata = self._dg.add_login_metadata(metadata)
         query_error = None
         try:
@@ -191,10 +192,16 @@ class Txn(object):
             mutation.cond = cond.encode('utf8')
         return mutation
 
-    def create_request(self, query=None, variables=None, mutations=None, commit_now=None):
+    def create_request(self, query=None, variables=None, mutations=None, commit_now=None, resp_format="JSON"):
+        if resp_format=="JSON":
+            resp_format = api.Request.RespFormat.JSON
+        elif resp_format =="RDF":
+            resp_format = api.Request.RespFormat.RDF
+        else: raise errors.TransactionError('Response format should be either RDF or JSON')
+
         """Creates a request object"""
         request = api.Request(start_ts = self._ctx.start_ts, commit_now=commit_now,
-                              read_only=self._read_only, best_effort=self._best_effort)
+                              read_only=self._read_only, best_effort=self._best_effort, resp_format = resp_format)
 
         if variables is not None:
             for key, value in variables.items():
@@ -305,7 +312,7 @@ class Txn(object):
         elif self._ctx.start_ts != src.start_ts:
             # This condition should never be true.
             raise errors.TransactionError('StartTs mismatch')
-
+        self._ctx.hash = src.hash
         self._ctx.keys.extend(src.keys)
         self._ctx.preds.extend(src.preds)
 
